@@ -1,8 +1,8 @@
 /**************************************************
-* unit:    strings           release 0.26         *
+* unit:    strings           release 0.29         *
 * purpose: test of functionality of unit string   *
 * Licency: GPL                                    *
-* Copyright: (c) 1998-2024 Jaroslav Fojtik        *
+* Copyright: (c) 1998-2025 Jaroslav Fojtik        *
 ***************************************************/
 #ifdef _MSC_VER
     #include <windows.h> 
@@ -21,14 +21,17 @@
 #define heapcheck() 1
 #endif
 
-#ifdef Streams
-#include <iostream.h>
+
+#ifndef NO_itoa
+ #if defined(__EGC__) || defined(__GNUC__)
+  #if (__GNUC__ >= 5) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 8)
+    #define NO_itoa
+  #endif
+ #endif
 #endif
 
-#if defined(__EGC__) || defined(__GNUC__)
- #if (__GNUC__ >= 5) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 8)
-  #include "../test/itoa.c"
- #endif
+#ifdef NO_itoa
+ #include "../test/itoa.c"
 #endif
 
 
@@ -102,7 +105,8 @@ int main(int argc, char *argv[])
 {
 string s0,s1,s2,s3,s4;
 char *ch;
-int i,j;
+int i;
+unsigned j;
 unsigned u;
 char c;
 //string *ps=new string[10]("ahoj");
@@ -110,7 +114,7 @@ int Ops;
 
 
  puts("");
- puts("<<<strings>>> (c)1998-2024 Jaroslav Fojtik");
+ puts("<<<strings>>> (c)1998-2025 Jaroslav Fojtik");
  printf("              This program tests the string unit, release %d.%d\n",
 	STRINGS_VERSION>>8, STRINGS_VERSION&0xFF);
 
