@@ -2,7 +2,7 @@
 * Unit:    matrix            release 0.10              *
 * Purpose: general manipulation with matrices          *
 * Licency: GPL or LGPL                                 *
-* Copyright: (c) 1998-2021 Jaroslav Fojtik             *
+* Copyright: (c) 1998-2025 Jaroslav Fojtik             *
 ********************************************************/
 #include <stdio.h>
 #include <stdlib.h>
@@ -264,7 +264,7 @@ static FLOAT PlaceHolder;
 
 
 template <class FLOAT>
-void matrix<FLOAT>::row(TSIZE y, FLOAT *DataRow)
+void matrix<FLOAT>::row(TSIZE y, const FLOAT *DataRow)
 {
 FLOAT *R;
 TSIZE x;
@@ -1002,7 +1002,7 @@ FLOAT Det;
      RaiseError(MatrixId|NotSquare,(void *)this);
      return 0;
      }
- if(size2D==0 || size1D==0) return 0;
+ if(size2D==0) return 0;	// size1D is a same as size1D e.g==0
 
  matrix<FLOAT> A;
  A=triangle(matrix<FLOAT>());
@@ -1042,7 +1042,7 @@ int i;
      RaiseError(MatrixId|NotSquare,(void *)this);	//matrix::exp: matrix not quadratic.
      return matrix<FLOAT>();
      }
- if(size2D==0 || size1D==0 || data==NULL) return matrix<FLOAT>();
+ if(size2D==0 || data==NULL) return matrix<FLOAT>(); 	// size1D is a same as size1D e.g==0
 
  result.ones();
  i=2;
