@@ -1,7 +1,7 @@
 #ifndef _TYPEDEFS_H_
 #define _TYPEDEFS_H_
 /******** Definition of items with uniquely size **********
-(c) 1997-2024 Jaroslav Fojtik
+(c) 1997-2025 Jaroslav Fojtik
    if you don't use below mentionted compiler, please correct this items
    for your compiler and send me your correction to:
 		JaFojtik@seznam.cz or JaFojtik@yandex.com
@@ -9,14 +9,16 @@
 
 List of supported types:
 
-   Type  Alternate  Size & Description
-   -----+---------+------+---------------------
-   uint8_t    BYTE   1 byte  =  8 bit
-   int8_t    SBYTE   1 byte  =  8 bit signed
-   uint16_t   WORD   2 bytes = 16 bit
-   int16_t   SWORD   2 bytes = 16 bit signed
-   uint32_t  DWORD   4 bytes = 32 bit
-   int32_t  SDWORD   4 bytes = 32 bit signed
+   Type         Size & Description
+   --------+---------+---------------------------
+   uint8_t   1 byte  =  8 bit
+   int8_t    1 byte  =  8 bit signed
+   uint16_t  2 bytes = 16 bit
+   int16_t   2 bytes = 16 bit signed
+   uint32_t  4 bytes = 32 bit
+   int32_t   4 bytes = 32 bit signed
+   uint64_t  8 bytes = 64 bit
+   int64_t   8 bytes = 64 bit signed
 
 ***************************************************************/
 
@@ -65,7 +67,7 @@ extern "C" {
   #endif
  #endif
 
- #ifndef HI_ENDIAN
+ #if !defined(NATIVE_ACCESS) && !defined(HI_ENDIAN) && !defined(__ARM_FEATURE_UNALIGNED)
   #define NATIVE_ACCESS
  #endif
 
@@ -390,16 +392,16 @@ void ST_FLOAT_SWAP(void *b, float f);
 
 
 #ifndef LD_UINT16_HI
-#define LD_UINT16_HI(ptr)	(uint16_t)(((uint16_t)*(uint8_t*)((ptr))<<8)|(uint16_t)*((uint8_t*)(ptr)+1))
+ #define LD_UINT16_HI(ptr)	(uint16_t)(((uint16_t)*(uint8_t*)((ptr))<<8)|(uint16_t)*((uint8_t*)(ptr)+1))
 #endif
 #ifndef LD_UINT32_HI
-#define LD_UINT32_HI(ptr)	(uint32_t)(((uint32_t)*(uint8_t*)((ptr))<<24)|((uint32_t)*(uint8_t*)((ptr)+1)<<16)|((uint16_t)*(uint8_t*)((ptr)+2)<<8)|*((uint8_t*)(ptr)+3))
+ #define LD_UINT32_HI(ptr)	(uint32_t)(((uint32_t)*(uint8_t*)((ptr))<<24)|((uint32_t)*(uint8_t*)((ptr)+1)<<16)|((uint16_t)*(uint8_t*)((ptr)+2)<<8)|*((uint8_t*)(ptr)+3))
 #endif
 #ifndef ST_UINT16_HI
-#define ST_UINT16_HI(ptr,val)	*((uint8_t*)(ptr)+1)=(uint8_t)(val); *(uint8_t*)((ptr))=(uint8_t)((uint16_t)(val)>>8)
+ #define ST_UINT16_HI(ptr,val)	*((uint8_t*)(ptr)+1)=(uint8_t)(val); *(uint8_t*)((ptr))=(uint8_t)((uint16_t)(val)>>8)
 #endif
 #ifndef ST_UINT32_HI
-#define ST_UINT32_HI(ptr,val)	*((uint8_t*)(ptr)+3)=(uint8_t)(val); *(uint8_t*)((ptr)+2)=(uint8_t)((uint16_t)(val)>>8); *(uint8_t*)((ptr)+1)=(uint8_t)((uint32_t)(val)>>16); *(uint8_t*)((ptr))=(uint8_t)((uint32_t)(val)>>24)
+ #define ST_UINT32_HI(ptr,val)	*((uint8_t*)(ptr)+3)=(uint8_t)(val); *(uint8_t*)((ptr)+2)=(uint8_t)((uint16_t)(val)>>8); *(uint8_t*)((ptr)+1)=(uint8_t)((uint32_t)(val)>>16); *(uint8_t*)((ptr))=(uint8_t)((uint32_t)(val)>>24)
 #endif
 
 #if defined(uint64_t_defined)
