@@ -1,5 +1,5 @@
 /*****************************************************
-* Unit:    stacks           release 0.5              *
+* Unit:    stacks           release 0.7              *
 * Purpose: general manipulation with FIFO structures *
 * Licency: GPL or LGPL                               *
 ******************************************************/
@@ -8,15 +8,15 @@
 #include <string.h>
 #include <ctype.h>
 #include <stdio.h>
-#ifdef Streams
- #include <iostream.h>
-#endif
+//#ifdef Streams
+// #include <iostream.h>
+//#endif
 
 #include "typedfs.h"
-#include <stacks.h>
+#include "stacks.h"
 
 
-//Constructors Of set class
+/// Constructors Of stack class.
 stack::stack(void)
 {
  data=NULL;
@@ -40,12 +40,6 @@ stack &stack::operator=(const stack & s)
  return(*this);
 }
 
-//Destructor Of class set
-//stack::~stack(void)
-//{
-// erase(*this);
-//}
-
 
 int stack::pop(void)
 {
@@ -78,6 +72,7 @@ void stack::push(int value)
      {
      Allocated=Level=0;
      RaiseError(StackId|No_Memory,this); //Memory Exhausted
+     return;		// Prevent accessing data[]
      }
    }
  data[Level++] = value;
