@@ -1,5 +1,5 @@
 /****************************************************
-* unit:    strings           release 0.29           *
+* unit:    strings           release 0.30           *
 * purpose: general manipulation with text strings   *
 * Licency: GPL or LGPL                              *
 * Copyright: (c) 1998-2025 Jaroslav Fojtik          *
@@ -238,25 +238,25 @@ void string::resize(unsigned int NewMaxLen)
 //-------------------------------------
 //Family of Operator =
 
-//Oparator for filling string from char
+/// Operator for filling string from char.
 string &string::operator=(char c)
 {
-if(c==0)
+ if(c==0)
       {
       if(ch!=NULL) *ch=0;
       size=0;
       return(*this);
       }
 
-if(maxlen<1)
+ if(maxlen<1)
 	{
-	if(maxlen!=0) free(ch);
+	//if(maxlen!=0) free(ch); // maxlen could be 0 only here
 	maxlen = FIX_ALLOC(2);
 	ch = (char *)malloc(maxlen);
 	maxlen--;
 	}
 
-if(ch!=NULL)
+ if(ch!=NULL)
 	{
 	size=1;
 	ch[0]=c;
@@ -264,8 +264,8 @@ if(ch!=NULL)
 	return(*this);
 	}
 
-maxlen=size=0;
-RaiseError(StringsId|No_Memory,this); //Memory Exhausted
+ maxlen=size=0;
+ RaiseError(StringsId|No_Memory,this); //Memory Exhausted
 return(*this);
 }
 
@@ -672,16 +672,19 @@ temp_string::temp_string(const char *str, int i)
 
 string &string::operator=(temp_string &s)
 {
- if(s.size==0)
-	{
-	size = 0;
-	if(maxlen>0) *ch=0;
-	return(*this);
-	}
- if(ch)
-   if(maxlen>0 || size==0) free(ch);
- ch=s.ch; size=s.size; maxlen=s.maxlen;
- s.ch=NULL; s.size=s.maxlen=0;
+ if(this != (string*)&s)		// Do not assign to self.
+ {
+   if(s.size==0)
+   {
+     size = 0;
+     if(maxlen>0) *ch=0;
+     return(*this);
+   }
+   if(ch)
+     if(maxlen>0 || size==0) free(ch);
+   ch=s.ch; size=s.size; maxlen=s.maxlen;
+   s.ch=NULL; s.size=s.maxlen=0;
+ }
 return(*this);
 }
 
@@ -772,12 +775,12 @@ return(temp_string(s));
 
 temp_string copy(const string &s, int from, int len)
 {
-if((from>length(s)) || (len<=0) || (from<0) || (length(s)==0))
-	{
-	return temp_string();
-	}
+ if((from<0) || (unsigned)from>length(s) || len<=0 || length(s)==0)
+ {
+   return temp_string();
+ }
 
-return temp_string(s()+from,len);
+ return temp_string(s()+from,len);
 }
 
 
