@@ -40,6 +40,12 @@ int UseGrStyle(const char ReqFlag)
 		   {Flag1=STYLE_USED;return(LaTeX_str1);}  \
   if(Flag2>=STYLE_NOTUSED) {Flag2=STYLE_USED;return(LaTeX_str2);}
 
+#define SWITCH_ARAB(LaTeX_str) if(arabtex>=0) \
+  { \
+  cq->RequiredFont = FONT_ARABIC;	/*Arabic font*/ \
+  return LaTeX_str; \
+  }
+
 #define SWITCH_CYR(LaTeX_str) if(Cyrillic>=0) \
   { \
   cq->RequiredFont = FONT_CYRILLIC; /*Cyrillic font*/ \
@@ -75,7 +81,7 @@ uint16_t UserCharSet(unsigned char char_code, TconvertedPass1 *cq)
 }
 
 
-static char buffer[4];
+static char buffer[5];
 
 const char *ExpandPlainChar(uint8_t char8)
 {
@@ -103,11 +109,21 @@ const char *ExpandUTF8(uint16_t wchar)
     return buffer;
   }
 
-  buffer[0] = 0xC8 | (wchar>>12);
-  buffer[1] = 0x80 | ((wchar>>6) & 0x3F);
-  buffer[2] = 0x80 | (wchar & 0x3F);
-  buffer[3] = 0;
-  return buffer;
+  //if(wchar<=0xFFFF)	// we are limited here to uint16_t
+  {
+    buffer[0] = 0xE0 | (wchar>>12);
+    buffer[1] = 0x80 | ((wchar>>6) & 0x3F);
+    buffer[2] = 0x80 | (wchar & 0x3F);
+    buffer[3] = 0;
+    return buffer;
+  }
+/*
+  buffer[0] = 0xF0 | (wchar>>18);
+  buffer[1] = 0x80 | ((wchar>>12) & 0x3F);
+  buffer[2] = 0x80 | ((wchar>>6) & 0x3F);
+  buffer[3] = 0x80 | (wchar & 0x3F);
+  buffer[4] = 0;
+*/
 
 //static char buffer[17];
 // sprintf(buffer,"\\unichar{\"%4.4X\"}", wchar);
