@@ -52,7 +52,7 @@ return(PathName);
 }
 
 
-void codepage::InsertCharDesc(uint16_t position, const char *Name)
+void codepage::InsertCharDesc(uint16_t position, const char *Name, bool warning)
 {
 if(Name==NULL) return;
 if(*Name==0) return;
@@ -68,10 +68,11 @@ if(position>=Allocated)
 
 if(characters[position]!=NULL)
 	{
-        printf("\n<%s>",characters[position]);
-
+        if(warning)
+          printf("\n<%s>",characters[position]);
 	if(!strcmp(characters[position],Name)) return;
-	printf("Warning: redefinition of character 0x%X \"%s\" -> \"%s\" in \"%s\"!\n",
+        if(warning)
+	  printf("Warning: redefinition of character 0x%X \"%s\" -> \"%s\" in \"%s\"!\n",
 		position,characters[position],Name,(name==NULL)?"":name);
 	free(characters[position]);
 	characters[position] = NULL;
