@@ -4,6 +4,7 @@
 #include "raster.h"
 
 
+/** This error is emitted when some internal failure of library occurs. */
 void AbstractError(const char *Name)
 {
  fprintf(stderr, "Abstract function '%s' called!\n", Name==NULL?"":Name);
@@ -12,7 +13,7 @@ void AbstractError(const char *Name)
 
 
 #if 0 // #ifdef ERROR_HANDLER
- void RaiseError(int ErrNo,void *Instance)
+ void RaiseError(int ErrNo, const void *Instance)
      {
      const char *str="?";
      switch(ErrNo >> 8)
