@@ -1,6 +1,6 @@
 /***************************************************************************
- * Unit:    raster            release 0.33                                 *
- * Purpose: Prototypes for general manipulation n dimensional matrices     *
+ * Unit:    image               release 0.81                               *
+ * Purpose: Upper layer for processing raster images                       *
  * Modul:   raster.cc                                                      *
  * Licency: GPL or LGPL                                                    *
  * Copyright: (c) 1998-2025 Jaroslav Fojtik                                *
@@ -15,7 +15,7 @@
 #include "stringa.h"
 
 
-#define RAS_IMG_VERSION (0x200 | 80)
+#define RAS_IMG_VERSION (0x200 | 81)
 
 // Definition of errors while Loading/Saving File(s)
 #define ErrOK		  0
@@ -51,6 +51,8 @@ public:
   PropertyItem(const char *NewName, unsigned IniSize);
   virtual ~PropertyItem();
 
+  bool Append(const void *OutCode, unsigned CodeSize);
+
   mutable short UsageCount;
   void *Data;
   uint32_t DataSize;
@@ -61,7 +63,7 @@ public:
 class PropertyItemInt: public PropertyItem
 {
 public:
-  PropertyItemInt(const char *NewName, int Value): PropertyItem(NewName,sizeof(int)) {*(int*)Data=Value;}
+  PropertyItemInt(const char *NewName, int Value);
 };
 
 
