@@ -1,10 +1,13 @@
 /******************************************************************************
- * program:     rasimg library                                                *
+ * program:     rasimg library               raster 0.37                      *
  * function:    Usefull block operations. 				      *
  * modul:       img_tool.c                                                    *
  * licency:     GPL or LGPL                                                   *
  ******************************************************************************/
 #include <stdio.h>
+#ifdef _MSC_VER
+#include <stdlib.h>	/* _byteswap_ushort, .... */
+#endif
 #include "img_tool.h"
 
 #include "typedfs.h"
@@ -12,14 +15,20 @@
 
 void swab16(unsigned char *block, int PixelCount)
 {
+#if !(defined(ST_UINT16_CPU) && defined(LD_UINT16_SWAP))
 unsigned char tmp;
+#endif
 
 #ifdef NULL
  if(block==NULL) return;
 #endif
  while(PixelCount-->0)
  {
+#if defined(ST_UINT16_CPU) && defined(LD_UINT16_SWAP)
+   ST_UINT16_CPU(block,LD_UINT16_SWAP(block));
+#else
    tmp=block[1]; block[1]=block[0]; block[0]=tmp;
+#endif
    block += 2;
  }
 }
@@ -27,15 +36,21 @@ unsigned char tmp;
 
 void swab32(unsigned char *block, int PixelCount)
 {
+#if !(defined(ST_UINT32_CPU) && defined(LD_UINT32_SWAP))
 unsigned char tmp;
+#endif
 
 #ifdef NULL
  if(block==NULL) return;
 #endif
  while(PixelCount-->0)
  {
+#if defined(ST_UINT32_CPU) && defined(LD_UINT32_SWAP)
+   ST_UINT32_CPU(block,LD_UINT32_SWAP(block));
+#else
    tmp=block[3]; block[3]=block[0]; block[0]=tmp;
    tmp=block[2]; block[2]=block[1]; block[1]=tmp;
+#endif
    block += 4;
  }
 }
@@ -43,17 +58,23 @@ unsigned char tmp;
 
 void swab64(unsigned char *block, int PixelCount)
 {
+#if !(defined(ST_UINT64_CPU) && defined(LD_UINT64_SWAP))
 unsigned char tmp;
+#endif
 
 #ifdef NULL
  if(block==NULL) return;
 #endif
  while(PixelCount-->0)
  {
+#if defined(ST_UINT64_CPU) && defined(LD_UINT64_SWAP)
+   ST_UINT64_CPU(block,LD_UINT64_SWAP(block));  
+#else
    tmp=block[7]; block[7]=block[0]; block[0]=tmp;
    tmp=block[6]; block[6]=block[1]; block[1]=tmp;
    tmp=block[5]; block[5]=block[2]; block[2]=tmp;
    tmp=block[4]; block[4]=block[3]; block[3]=tmp;
+#endif
    block += 8;
  }
 }
@@ -260,10 +281,55 @@ int32_t X;
 
   while(PixelCount>=2)
   {
-    const int32_t Y = 256 * *(yuyv++);
-    const signed char U = *yuyv++ - 128;
-    const int32_t Y2 = 256 * *(yuyv++);
-    const signed char V = *yuyv++ - 128;
+    const int32_t Y = 256 * yuyv[0];
+    const signed char U = yuyv[1] - 128;
+    const int32_t Y2 = 256 * yuyv[2];
+    const signed char V = yuyv[3] - 128;
+    yuyv += 4;
+
+    X = (Y + 291*V) >> 8;	// Y + 1.137*V;
+    if(X>254) OutData[0]=255;
+    else if(X<0) OutData[0]=0;
+    else OutData[0] = X;
+    X = (Y -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
+    if(X>254) OutData[1]=255;
+    else if(X<0) OutData[1]=0;
+    else OutData[1] = X;
+    X = (Y + 521*U) >> 8;	// Y + 2.034*U;
+    if(X>254) OutData[2]=255;
+    else if(X<0) OutData[2]=0;
+    else OutData[2] = X;
+
+    X = (Y2 + 291*V) >> 8;	// Y + 1.137*V;
+    if(X>254) OutData[3]=255;
+    else if(X<0) OutData[3]=0;
+    else OutData[3] = X;
+    X = (Y2 -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
+    if(X>254) OutData[4]=255;
+    else if(X<0) OutData[4]=0;
+    else OutData[4] = X;
+    X = (Y2 + 521*U) >> 8;	// Y + 2.034*U;
+    if(X>254) OutData[5]=255;
+    else if(X<0) OutData[5]=0;
+    else OutData[5] = X;
+
+    OutData += 6;
+    PixelCount -= 2;
+  }
+}
+
+
+void UYVY_RGB(unsigned char *OutData, const unsigned char *uyvy, unsigned PixelCount)
+{
+int32_t X;
+
+  while(PixelCount>=2)
+  {
+    const signed char U = uyvy[0] - 128;
+    const int32_t Y = 256 * uyvy[1];
+    const signed char V = uyvy[2] - 128;
+    const int32_t Y2 = 256 * uyvy[3];
+    uyvy += 4;
 
     X = (Y + 291*V) >> 8;	// Y + 1.137*V;
     if(X>255) OutData[0]=255;
@@ -278,22 +344,20 @@ int32_t X;
     else if(X<0) OutData[2]=0;
     else OutData[2] = X;
 
-    OutData += 3;
-
     X = (Y2 + 291*V) >> 8;	// Y + 1.137*V;
-    if(X>255) OutData[0]=255;
-    else if(X<0) OutData[0]=0;
-    else OutData[0] = X;
+    if(X>255) OutData[3]=255;
+    else if(X<0) OutData[3]=0;
+    else OutData[3] = X;
     X = (Y2 -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
-    if(X>255) OutData[1]=255;
-    else if(X<0) OutData[1]=0;
-    else OutData[1] = X;
+    if(X>255) OutData[4]=255;
+    else if(X<0) OutData[4]=0;
+    else OutData[4] = X;
     X = (Y2 + 521*U) >> 8;	// Y + 2.034*U;
-    if(X>255) OutData[2]=255;
-    else if(X<0) OutData[2]=0;
-    else OutData[2] = X;
+    if(X>255) OutData[5]=255;
+    else if(X<0) OutData[5]=0;
+    else OutData[5] = X;
 
-    OutData += 3;    
+    OutData += 6;    
     PixelCount -= 2;
   }
 }
@@ -305,40 +369,39 @@ int32_t X;
 
   while(PixelCount>=2)
   {
-    const int32_t Y = 256 * *(yuyv++);
-    const signed char V = *yuyv++ - 128;
-    const int32_t Y2 = 256 * *(yuyv++);
-    const signed char U = *yuyv++ - 128;
+    const int32_t Y = 256 * yuyv[0];
+    const signed char V = yuyv[1] - 128;
+    const int32_t Y2 = 256 * yuyv[2];
+    const signed char U = yuyv[3] - 128;    
+    yuyv += 4;
 
     X = (Y + 291*V) >> 8;	// Y + 1.137*V;
-    if(X>255) OutData[0]=255;
-    else if(X<0) OutData[0]=0;
+    if(X>254) OutData[0]=255;
+    else if(X<=0) OutData[0]=0;
     else OutData[0] = X;
     X = (Y -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
-    if(X>255) OutData[1]=255;
-    else if(X<0) OutData[1]=0;
+    if(X>254) OutData[1]=255;
+    else if(X<=0) OutData[1]=0;
     else OutData[1] = X;
     X = (Y + 521*U) >> 8;	// Y + 2.034*U;
-    if(X>255) OutData[2]=255;
-    else if(X<0) OutData[2]=0;
+    if(X>254) OutData[2]=255;
+    else if(X<=0) OutData[2]=0;
     else OutData[2] = X;
 
-    OutData += 3;
-
     X = (Y2 + 291*V) >> 8;	// Y + 1.137*V;
-    if(X>255) OutData[0]=255;
-    else if(X<0) OutData[0]=0;
-    else OutData[0] = X;
+    if(X>254) OutData[3]=255;
+    else if(X<=0) OutData[3]=0;
+    else OutData[3] = X;
     X = (Y2 -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
-    if(X>255) OutData[1]=255;
-    else if(X<0) OutData[1]=0;
-    else OutData[1] = X;
+    if(X>254) OutData[4]=255;
+    else if(X<=0) OutData[4]=0;
+    else OutData[4] = X;
     X = (Y2 + 521*U) >> 8;	// Y + 2.034*U;
-    if(X>255) OutData[2]=255;
-    else if(X<0) OutData[2]=0;
-    else OutData[2] = X;
+    if(X>254) OutData[5]=255;
+    else if(X<=0) OutData[5]=0;
+    else OutData[5] = X;
 
-    OutData += 3;    
+    OutData += 6;
     PixelCount -= 2;
   }
 }
