@@ -304,6 +304,22 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 	NULL);
  #endif
 
+
+#ifdef SupportPDB
+ ImplementReader(PDB,".PDB")
+ #if SupportPDB>=4 || SupportPDB==2
+	LoadPicturePDB,
+ #else
+	NULL,
+ #endif
+ #if SupportPDB>=3
+	SavePicturePDB);
+ #else
+	NULL);
+ #endif
+#endif
+
+
 int SavePicturePGM(const char *Name,const Image &Img);
 TImageFileHandler HANDLER_PGM(".PGM",
  #if SupportPBM>=4 || SupportPBM==2
