@@ -68,6 +68,38 @@ PropertyItem::~PropertyItem()
 }
 
 
+bool PropertyItem::Append(const void *OutCode, unsigned CodeSize)
+{
+  if(OutCode==NULL) return CodeSize==0;
+  if(Data==NULL)
+  {
+    Data = malloc(CodeSize);
+    if(Data==NULL) return false;
+    memcpy(Data,OutCode,CodeSize);
+    DataSize = CodeSize;
+  }
+  else
+  {
+    void *Data2 = realloc(Data,CodeSize+DataSize);
+    if(Data2==NULL) return false;
+    Data = Data2;
+    memcpy((uint8_t*)Data+DataSize, OutCode, CodeSize);
+    DataSize += CodeSize;
+  }
+  return true;
+}
+
+
+PropertyItemInt::PropertyItemInt(const char *NewName, int Value): PropertyItem(NewName,sizeof(int))
+{
+  if(Data)
+      *(int*)Data=Value;
+}
+
+
+////////////////////////////////////////////////////
+
+
 PropertyList::~PropertyList()
 {
   if(pProperties != NULL)
