@@ -1082,7 +1082,7 @@ bool NeedLocalPalette = false;
       PropComment = Img.Properties.Find("comment",count);
       if(PropComment!=NULL && PropComment->Data!=NULL)
       {
-        char Blob[2] = {0x21, 0xFE};
+        unsigned char Blob[2] = {0x21, 0xFE};
         fwrite(Blob,1,2,f);
         count = PropComment->DataSize;
         uint8_t *Offs = (uint8_t*)PropComment->Data;
