@@ -1,5 +1,5 @@
 /***************************************************************
-* Unit:    rasters           release 0.37                      *
+* Unit:    raster image      release 0.38                      *
 * Purpose: Test of functionality of raster container library.  *
 * Licency: GPL (only)                                          *
 * Copyright: (c) 1998-2025 Jaroslav Fojtik                     *
@@ -39,20 +39,20 @@ void Benchmark(void);
 void B2(void);
 
 FILE *TempF;
-const char vec[] = {1,2,4,8,16,24,32
+const signed char vec[] = {1,2,4,8,16,24,32
 #ifdef QWORD
 		,64
 #endif
 		,-32,-64
 		};
-unsigned long val_max[] = {2,4,16,256,65536,0x1000000,0xFFFFFFFF
+const unsigned long val_max[] = {2,4,16,256,65536,0x1000000,0xFFFFFFFF
 #ifdef QWORD
 		,0xFFFFFFFF
 #endif
 		,0xFFFFFFFF,0xFFFFFFFF};
 
-char vecRGB[] = {8,16};
-const char vecFlt[] = {-32,-64};
+const signed char vecRGB[] = {8,16};
+const signed char vecFlt[] = {-32,-64};
 
 #define MAX_K (sizeof(vec)-2)
 
@@ -706,7 +706,7 @@ int Ops;
        uint8_t val = (i^j) & 0xFF;
        if(Buffer[i] != val)
        {
-         printf("Gaus1D_u32 corrupted memory before block on pos %d %X!=%Xh, position %d", i, Buffer[i], val, j);
+         printf("Gaus1D_u32 corrupted memory before block on pos %d %X!=%Xh, block size %d", i, Buffer[i], val, j);
          Err = -21;
          goto Abnormal_End;
        }
@@ -716,7 +716,7 @@ int Ops;
        uint8_t val = (i^j) & 0xFF;
        if(Buffer[i] != val)
        {
-         printf("Gaus1D_u32 corrupted memory behind block pos %d %u!=%u, position %d", i, Buffer[i], val, j);
+         printf("Gaus1D_u32 corrupted memory behind block pos %d %u!=%u, block size %d", i, Buffer[i], val, j);
          Err = -22;
          goto Abnormal_End;
        }
@@ -1184,6 +1184,7 @@ int Ops;
      {
        const uint8_t BytesVal1[4] = {((i^j)&0xFF), (((i+1)^j)&0xFF), (((i+2)^j)&0xFF), (((i+3)^j)&0xFF)};
        const uint32_t val1 = *(uint32_t*)BytesVal1;
+       //const uint32_t val1 = ((i^j)&0xFF) | ((((i+1)^j)&0xFF)<<8) | ((((i+2)^j)&0xFF)<<16) | ((((i+3)^j)&0xFF)<<24);
        const uint32_t val2 = *(uint32_t*)(Buffer+i);
        const uint32_t val3 = *(uint32_t*)(Buffer2+i);
        const uint32_t val4 = (val1>>1)+0x80000000 -  (val3>>1);
@@ -2157,6 +2158,281 @@ int Ops;
 
 
 
+	/////////////////////
+
+   printf(" UYVY_RGB\n");
+   
+   Buffer = (unsigned char*)malloc(4*512);
+   Buffer2 = (unsigned char*)malloc(3*512);
+
+   for(i=0; i<256; i++)
+   {
+     Buffer[2*i+1] = i;
+   }
+   for(i=0; i<128; i++)
+   {
+     Buffer[4*i+0] = 128;
+     Buffer[4*i+2] = 128;
+   }
+
+   UYVY_RGB(Buffer2, Buffer, 256);
+
+   for(i=0; i<256; i++)
+   {
+     if(Buffer2[3*i] != i)
+     {
+       printf("UYVY_RGB wrong R compound %u!=%u", i, Buffer2[3*i]);
+       Err = -41;
+       goto Abnormal_End;
+     }
+     if(Buffer2[3*i+1] != i)
+     {
+       printf("UYVY_RGB wrong G compound %u!=%u", i, Buffer2[3*i+1]);
+       Err = -42;
+       goto Abnormal_End;
+     }
+     if(Buffer2[3*i+2] != i)
+     {
+       printf("UYVY_RGB wrong B compound %u!=%u", i, Buffer2[3*i+2]);
+       Err = -43;
+       goto Abnormal_End;
+     }
+   }
+
+	// Overflow test.
+   for(j=0; j<6; j++)
+   {
+     FeedBuffer(Buffer,j);
+
+     UYVY_RGB(Buffer2, Buffer, 512);
+
+     for(i=0; i<256; i++)
+     {
+       int32_t Y = Buffer[4*i+1];
+       int32_t Y2 = Buffer[4*i+3];
+       int32_t U = Buffer[4*i] - 128;
+       int32_t V = Buffer[4*i+2] - 128;
+       uint8_t R1 = Buffer2[6*i];
+       uint8_t R2 = Buffer2[6*i+3];
+       uint8_t G1 = Buffer2[6*i+1];
+       uint8_t G2 = Buffer2[6*i+4];
+       uint8_t B1 = Buffer2[6*i+2];
+       uint8_t B2 = Buffer2[6*i+5];
+
+       int32_t X = (256*Y + 291*V) >> 8;	// Y + 1.137*V;
+       if(X<0) X=0;
+       if(X>255) X=255;
+       if(X != R1)
+       {
+         printf("UYVY_RGB wrong R1 compound %u!=%u", X, R1);
+         Err = -41;
+         goto Abnormal_End;
+       }
+     
+       X = (256*Y2 + 291*V) >> 8;		// Y + 1.137*V;
+       if(X<0) X=0;
+       if(X>255) X=255;
+       if(X != R2)
+       {
+         printf("UYVY_RGB wrong R2 compound %u!=%u", X, R2);
+         Err = -41;
+         goto Abnormal_End;
+       }
+
+       X = (256*Y -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
+       if(X<0) X=0;
+       if(X>255) X=255;
+       if(X != G1)
+       {
+         printf("UYVY_RGB wrong G1 compound %u!=%u", X, G1);
+         Err = -41;
+         goto Abnormal_End;
+       }     
+       X = (256*Y2 -102*U - 148*V) >> 8; // Y - 0.397*U - 0.58*V;
+       if(X<0) X=0;
+       if(X>255) X=255;
+       if(X != G2)
+       {
+         printf("UYVY_RGB wrong G2 compound %u!=%u", X, G2);
+         Err = -41;
+         goto Abnormal_End;
+       }
+
+       X = (256*Y + 521*U) >> 8;	// Y + 2.034*U;
+       if(X<0) X=0;
+       if(X>255) X=255;
+       if(X != B1)
+       {
+         printf("UYVY_RGB wrong B1 compound %u!=%u", X, B1);
+         Err = -41;
+         goto Abnormal_End;
+       }     
+       X = (256*Y2 + 521*U) >> 8;	// Y + 2.034*U;
+       if(X<0) X=0;
+       if(X>255) X=255;
+       if(X != B2)
+       {
+         printf("UYVY_RGB wrong B2 compound %u!=%u", X, B2);
+         Err = -41;
+         goto Abnormal_End;
+       }
+     }
+   }
+
+
+   for(i=0; i<512; i++)
+   {
+     Buffer[2*i+1] = i/2;
+   }
+   for(i=0; i<256; i++)
+   {
+     Buffer[4*i] = 128 - 10;
+     Buffer[4*i+2] = 128;
+   }
+   UYVY_RGB(Buffer2, Buffer, 512);
+
+   for(i=0; i<512; i++)
+   {
+     if(Buffer2[3*i] != i/2)
+     {
+       printf("UYVY_RGB wrong R compound U=-10,V=0 %u!=%u", i/2, Buffer2[3*i]);
+       Err = -31;
+       goto Abnormal_End;
+     }
+     int G = (256*(i/2) + 102*10) / 256;
+     if(G>255) G=255;
+     if(Buffer2[3*i+1] != G)
+     {
+       printf("UYVY_RGB wrong G compound U=-10,V=0 %u!=%u", G, Buffer2[3*i+1]);
+       Err = -32;
+       goto Abnormal_End;
+     }
+     int B = (256*(i/2) - 521*10) / 256;
+     if(B<0) B=0;
+     if(Buffer2[3*i+2] != B)
+     {
+       printf("UYVY_RGB wrong B compound U=-10,V=0 %u!=%u", B, Buffer2[3*i+2]);
+       Err = -33;
+       goto Abnormal_End;
+     }
+   }
+
+   for(i=0; i<512; i++)
+   {
+     Buffer[2*i+1] = i/2;
+   }
+   for(i=0; i<256; i++)
+   {
+     Buffer[4*i] = 128 + 10;
+     Buffer[4*i+2] = 128;
+   }
+   UYVY_RGB(Buffer2, Buffer, 512);
+
+   for(i=0; i<512; i++)
+   {
+     if(Buffer2[3*i] != i/2)
+     {
+       printf("UYVY_RGB wrong R compound U=10,V=0 %u!=%u", i/2, Buffer2[3*i]);
+       Err = -31;
+       goto Abnormal_End;
+     }
+     int G = (256*(i/2) - 102*10) / 256;
+     if(G<0) G=0;
+     if(Buffer2[3*i+1] != G)
+     {
+       printf("UYVY_RGB wrong G compound U=10,V=0 %u!=%u", G, Buffer2[3*i+1]);
+       Err = -32;
+       goto Abnormal_End;
+     }
+     int B = (256*(i/2) + 521*10) / 256;
+     if(B>255) B=255;
+     if(Buffer2[3*i+2] != B)
+     {
+       printf("UYVY_RGB wrong B compound U=10,V=0 %u!=%u", B, Buffer2[3*i+2]);
+       Err = -33;
+       goto Abnormal_End;
+     }
+   }
+
+   for(i=0; i<512; i++)
+   {
+     Buffer[2*i+1] = i/2;
+   }
+   for(i=0; i<256; i++)
+   {
+     Buffer[4*i] = 128;
+     Buffer[4*i+2] = 128 - 10;
+   }
+   UYVY_RGB(Buffer2, Buffer, 512);
+
+   for(i=0; i<512; i++)
+   {
+     int R = (256*(i/2) - 291*10) / 256;
+     if(R<0) R=0;
+     if(Buffer2[3*i] != R)
+     {
+       printf("UYVY_RGB wrong R compound U=0,V=-10 %u!=%u", R, Buffer2[3*i]);
+       Err = -31;
+       goto Abnormal_End;
+     }
+     int G = (256*(i/2) + 148*10) / 256;
+     if(G>255) G=255;
+     if(Buffer2[3*i+1] != G)
+     {
+       printf("UYVY_RGB wrong G compound U=0,V=-10 %u!=%u", G, Buffer2[3*i+1]);
+       Err = -32;
+       goto Abnormal_End;
+     }     
+     if(Buffer2[3*i+2] != i/2)
+     {
+       printf("UYVY_RGB wrong B compound U=0,V=-10 %u!=%u", i/2, Buffer2[3*i+2]);
+       Err = -33;
+       goto Abnormal_End;
+     }
+   }
+
+
+   for(i=0; i<512; i++)
+   {
+     Buffer[2*i+1] = i/2;
+   }
+   for(i=0; i<256; i++)
+   {
+     Buffer[4*i] = 128;
+     Buffer[4*i+2] = 128 + 10;
+   }
+   UYVY_RGB(Buffer2, Buffer, 512);
+
+   for(i=0; i<512; i++)
+   {
+     int R = (256*(i/2) + 291*10) / 256;
+     if(R>255) R=255;
+     if(Buffer2[3*i] != R)
+     {
+       printf("UYVY_RGB wrong R compound U=0,V=10 %u!=%u", R, Buffer2[3*i]);
+       Err = -31;
+       goto Abnormal_End;
+     }
+     int G = (256*(i/2) - 148*10) / 256;
+     if(G<0) G=0;
+     if(Buffer2[3*i+1] != G)
+     {
+       printf("UYVY_RGB wrong G compound U=0,V=10 %u!=%u", G, Buffer2[3*i+1]);
+       Err = -32;
+       goto Abnormal_End;
+     }     
+     if(Buffer2[3*i+2] != i/2)
+     {
+       printf("UYVY_RGB wrong B compound U=0,V=10 %u!=%u", i/2, Buffer2[3*i+2]);
+       Err = -33;
+       goto Abnormal_End;
+     }
+   }
+
+   free(Buffer);
+   free(Buffer2);
+
+
 	/////////////////////
 
    printf(" YVYU_RGB\n");
@@ -2684,6 +2960,17 @@ void BenchYUYV_RGB(long i)
 }
 
 
+void BenchUYVY_RGB(long i)
+{
+  while(i-->0)
+  {
+    UYVY_RGB((unsigned char *)RA1->GetRow(),
+	    (unsigned char *)RA2->GetRow(),
+	    RA1->GetSize1D());
+  }
+}
+
+
 void BenchYVYU_RGB(long i)
 {
   while(i-->0)
@@ -2941,6 +3228,10 @@ for(unsigned i=0; i<RA2->Size1D; i++)
  f = AutoMeasure(BenchYVYU_RGB);  //RA1->Get(*RA2);
  printf("%8.5g	estimated throwput %.2f [Mpx/s]", f, (double)1000000*RA1->Size1D / (f*1000000.0));
 
+ printf("\nUYVY_RGB [us]:");
+ f = AutoMeasure(BenchUYVY_RGB);  //RA1->Get(*RA2);
+ printf("%8.5g	estimated throwput %.2f [Mpx/s]", f, (double)1000000*RA1->Size1D / (f*1000000.0));
+
  delete RA1;
  delete RA2;
 
