@@ -231,7 +231,7 @@ char RasterPlanes;
 
   fprintf(f,"\n"
       "%% define string to hold a scanline's worth of data\n"
-      "/pix %d string def\n"
+      "/pix %u string def\n"
       "\n"
       "%% define space for color conversions\n"
       "/grays %u string def  %% space for gray scale line\n"
@@ -275,7 +275,7 @@ char RasterPlanes;
    }
    fprintf(f,
      "%% dimensions of data\n"
-     "%u %u %d\n"					//%SizeX %SizeY %Planes
+     "%u %u %u\n"					//%SizeX %SizeY %Planes
      "%% mapping matrix\n"
      "[ %u 0 0 -%u 0 %u]\n\n",				//%SizeX %SizeY %SizeY
     Raster->Size1D, Raster->Size2D, Y,
@@ -305,7 +305,7 @@ char RasterPlanes;
 	{
 	case 12:		//palette images - less than 256 colors, RLE compressed.
 	  {
-	  Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);
+	  const Raster1DAbstract * const RasLine = Raster->GetRowRaster(Y);
 	  int CharsOnLine = 0;
 	  for(X=0; X<RasLine->GetSize1D(); X++)
 	    {
@@ -336,7 +336,7 @@ char RasterPlanes;
 	  {
 	  if(RasterPlanes==8)  //speedup trick for 8 planes
 	    {
-	    uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
+	    const uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
 	    for(X=0; X<BytesPerLine; X++)
 		{
 		Palette->Get(*ptrb++,&RGB);
@@ -346,7 +346,7 @@ char RasterPlanes;
 	     }
 	  else
 	     {
-	     Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);
+	     const Raster1DAbstract * const RasLine = Raster->GetRowRaster(Y);
 	     if(RasLine)
 	       for(X=0; X<RasLine->GetSize1D(); X++)
 		  {
@@ -362,7 +362,7 @@ char RasterPlanes;
    case ImageTrueColor:
 	   if(RasterPlanes==24) goto FAST_COPY;
 	   {
-	     Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);
+	     const Raster1DAbstract * const RasLine = Raster->GetRowRaster(Y);
 	     if(RasLine)
 	       {
 	       uint16_t chars_on_line = 0;
@@ -387,7 +387,7 @@ char RasterPlanes;
 	   RasterPlanes==4 ||
 	   RasterPlanes==1)	//speedup trick for 8, 4 and 1 planes
 	 {
-FAST_COPY:uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
+FAST_COPY:const uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
 	 for(X=0; X<BytesPerLine; X++)
 	    {
 	    fprintf(f,"%.2X",(unsigned)*ptrb++);
@@ -395,7 +395,7 @@ FAST_COPY:uint8_t *ptrb = (uint8_t *)Raster->GetRow(Y);
         }
 	else	/* Expand other bit depths to 8 bits */
 	{
-	 Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);	  
+	 const Raster1DAbstract * const RasLine = Raster->GetRowRaster(Y);	  
 	 if(RasLine)
 	   {
 	   int k = RasterPlanes - 8;
