@@ -202,6 +202,14 @@ unsigned i;
  
  switch(Attr)
  {
+   case 8:
+   case 12:	if(Cyrillic)			// {\itshape ... clears cyrillic font, needs to add again \cyr.
+		{
+		  if(a.Closed_Depth<=MaxAttributes)
+		      a.stack[a.Closed_Depth++] = Cyr_Font;
+		}
+	        break;
+
    case Cyr_Font: Cyrillic=true; break;
    case Heb_Font: cjHebrew=true; break;
    case Georgia_Font: mxedruli=true; break;
@@ -232,7 +240,7 @@ return(-1);
    It must generate some output to string.   */
 void _AttrOff(attribute & a, char Attr, string & s)
 {
-int pos;
+unsigned pos;
 
  s.erase();
 
@@ -337,7 +345,7 @@ void Attr_ON(TconvertedPass1 *cq, unsigned char b)
 	    fprintf(cq->err, _("\nWarning: Strange attribute %d!"),(int)b);
 	    }
 
-  sprintf(cq->ObjType, "Attr %d On",(int)b);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Attr %d On",(int)b);
 }
 
 
@@ -361,14 +369,14 @@ void Attr_OFF(TconvertedPass1 *cq, unsigned char b)
   if(!s.isEmpty()) fputs(s(),cq->strip);
 
 RejectAttr:
-  sprintf(cq->ObjType, "Attr %d Off",(int)b);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Attr %d Off",(int)b);
 }
 
 
 /** This procedure creates opening&closing sequence of attrs after that Base will have same items as A_new. */
 void AttrFit(attribute & Base, const attribute & A_New, string & s)
 {
-int i,pos;
+unsigned pos, i;
 const char *ch;
 
  s.erase();
@@ -631,7 +639,7 @@ void LineNumbering(TconvertedPass1 *cq, uint8_t LineNumbering)
   else
     AttrOff(cq,Line_Num);
 
-sprintf(cq->ObjType,"%sLine Num:%s", (LineNo>=STYLE_NOTUSED)?"":"!", (LineNumbering&1)?"On":"Off");
+  snprintf(cq->ObjType, sizeof(cq->ObjType),"%sLine Num:%s", (LineNo>=STYLE_NOTUSED)?"":"!", (LineNumbering&1)?"On":"Off");
 }
 
 
@@ -731,15 +739,14 @@ void Make_tableentry_tabset(TconvertedPass1 *cq)
   fprintf(cq->log,"\n#Make_tableentry_tabset() ");fflush(cq->log);
 #endif
   unsigned char b = 'S';
-  long j, FORLIM;
 
   fwrite(&b, sizeof(unsigned char), 1, cq->table);
 
   b = cq->num_of_tabs;
   fwrite(&b, sizeof(unsigned char), 1, cq->table);
 
-  FORLIM = cq->num_of_tabs;
-  for(j=0; j<FORLIM; j++)
+  const int FORLIM = cq->num_of_tabs;
+  for(int j=0; j<FORLIM; j++)
     Wr_word(cq->table, cq->tabpos[j]);
 }
 
@@ -834,7 +841,7 @@ void CellTable(TconvertedPass1 *cq)
        }
   else if(cq->char_on_line==CHAR_PRESENT) fputc(' ',cq->strip);
 
-  strcpy(cq->ObjType, "!Cell"+((cq->envir!='B')?0:1));
+  strcpy(cq->ObjType, "!Cell"+((cq->envir!='B')?0:1));  // This is correct because offset 1 hides '!'.
 }
 
 
@@ -1051,7 +1058,7 @@ uint8_t Red,Green,Blue;
   else fprintf(cq->strip, "\\color[rgb]{%1.2f,%1.2f,%1.2f}",
 	((float)Red)/0xFF,((float)Green)/0xFF,((float)Blue)/0xFF);
 
-  sprintf(cq->ObjType, "Color:%s", ColorType);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Color:%s", ColorType);
 }
 
 
@@ -1082,7 +1089,7 @@ void EndSection(TconvertedPass1 *cq, signed char WP)
     fread(&b, sizeof(unsigned char), 1, cq->wpd);   /* less attribuut-code */
     }
   else b=abs(WP);
-  sprintf(cq->ObjType, "End MarkToC %d",(int)b);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "End MarkToC %d",(int)b);
 
   if (b > 0) b -= cq->FirstSection;
 
@@ -1153,7 +1160,7 @@ void Flush_right(TconvertedPass1 *cq,char type)
 		  else fprintf(cq->strip, "\\hfill ");
 	   }
 
-  sprintf(cq->ObjType, "Flsh Rtg%s",type==1?" (dot)":"");
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Flsh Rtg%s",type==1?" (dot)":"");
 }
 
 
@@ -1441,7 +1448,7 @@ static const char JustWP3_2WP5[4]={0,2,3,1};
     }
 
 JustifEnd:
-  sprintf(cq->ObjType, "Justification %s",Direction);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Justification %s",Direction);
 }
 
 
@@ -1589,7 +1596,7 @@ int i;
     }
 
 Finish:
-  sprintf(cq->ObjType, "Lang:%s",CurLang);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Lang:%s",CurLang);
 }
 
 
@@ -1600,27 +1607,26 @@ void ParagraphNumber(TconvertedPass1 *cq)
   fprintf(cq->log,"\n#ParagraphNumber() ");fflush(cq->log);
 #endif
   unsigned char ParNumType;
-  int i;
   static char count='A';
 
 
   fread(&ParNumType, 1, 1, cq->wpd);
   ParNumType=ParNumType ^ 0x80;
   if(ParNumType>=0x80) strcpy(cq->ObjType, "ParNum:Auto");
-		  else sprintf(cq->ObjType, "ParNum:%d",(int)ParNumType);
+		  else snprintf(cq->ObjType, sizeof(cq->ObjType), "ParNum:%d",(int)ParNumType);
 
 /* check whether the section is opened */
-  for(i = 0; i < cq->attr.Closed_Depth; i++)
-	{
-	if(cq->attr.stack[i] >= First_com_section &&
-	   cq->attr.stack[i] <= Last_com_section) return;
-	}
+  for(unsigned i=0; i<cq->attr.Closed_Depth; i++)
+  {
+    if(cq->attr.stack[i] >= First_com_section &&
+	cq->attr.stack[i] <= Last_com_section) return;
+  }
 
 
   if (cq->attr.Closed_Depth!=cq->attr.Opened_Depth)
-	 {
+  {
 	 Open_All_Attr(cq->attr,cq->strip);
-	 }
+  }
   if(ParNumType>=0x80) {
 		       ParNumType=0x80;	//!!!!!!!!!!! opravit !!!!!
 		       fprintf(cq->strip, "\\label{ParNum_%c}\\ref{ParNum_%c}",count,count );
@@ -1751,7 +1757,7 @@ NoNumber_f:     fprintf(cq->strip,"\\fancyfoot{}\\fancyhead{}"); break;
       }
     }
 
-  sprintf(cq->ObjType, "Pg Numbering:%s",PgNumType);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Pg Numbering:%s",PgNumType);
 }
 
 
@@ -1875,7 +1881,7 @@ void SetEndnoteNum(TconvertedPass1 *cq, unsigned char WP)
   if(!EndNotes) EndNotes=true;		/* set up endnotes */
   if(EndNotes>0)
       fprintf(cq->strip, "\\setcounter{endnote}{%u}",(unsigned)CurEndNoteNum);
-  sprintf(cq->ObjType, "Endnote Num:%u",(unsigned)CurEndNoteNum);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Endnote Num:%u",(unsigned)CurEndNoteNum);
 }
 
 
@@ -1884,14 +1890,14 @@ void SetFont(TconvertedPass1 *cq, int PointSize, const char *FontName)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SetFont(%d,%s) ",PointSize,chk(FontName));fflush(cq->log);
 #endif
-int i;
+unsigned i;
 string TexFontName(FontName);
 const char *FontTblItem;
 
  if(FontName!=NULL)
    {
    TexFontName="WP:"+TexFontName;
-   for(i=0;i<length(FontTable);i++)	//Try to find LaTeX equivalent of WP font
+   for(i=0; i<length(FontTable); i++)	//Try to find LaTeX equivalent of WP font
 	{
 	if((FontTblItem=FontTable[i]) == NULL) continue;
 	if(strstr(FontTblItem,TexFontName())!=NULL)
@@ -1961,7 +1967,7 @@ const char *ig="!";
   SetFont(cq,PointSize,NULL);
   if(NFSS) ig="";
 
-  sprintf(cq->ObjType, "%sFont %2.2f",ig,float(PointSize)/50);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "%sFont %2.2f",ig,float(PointSize)/50);
 }
 
 
@@ -1998,7 +2004,7 @@ void SetFootnoteNum(TconvertedPass1 *cq, signed char WP)
 
 
   fprintf(cq->strip, "\\setcounter{footnote}{%u}",(unsigned)CurFootnoteNum);
-  sprintf(cq->ObjType, "Footnote Num:%u",(unsigned)CurFootnoteNum);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Footnote Num:%u",(unsigned)CurFootnoteNum);
 }
 
 
@@ -2034,7 +2040,7 @@ void SetPgNum(TconvertedPass1 *cq, unsigned char WP)
     }
 
   fprintf(cq->strip, "\\setcounter{page}{%u}",(unsigned)CurPgNum);
-  sprintf(cq->ObjType, "Pg Num:%u",(unsigned)CurPgNum);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Pg Num:%u",(unsigned)CurPgNum);
 }
 
 
@@ -2077,7 +2083,6 @@ void StartSection(TconvertedPass1 *cq, signed char WP)
   fprintf(cq->log,"\n#StartSection() ");fflush(cq->log);
 #endif
   unsigned char b;
-  int i;
 
   if(WP>0)
       {
@@ -2086,31 +2091,30 @@ void StartSection(TconvertedPass1 *cq, signed char WP)
       }
   else b=abs(WP); // direct set
 
-  sprintf(cq->ObjType, "Start MarkToC %d",(int)b);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "Start MarkToC %d",(int)b);
 
 			/* check whether any section is already opened */
-  for (i = 0; i < cq->attr.Closed_Depth; i++)
-	{
-	if(cq->attr.stack[i] >= First_com_section &&
-	   cq->attr.stack[i] <= Last_com_section)
-	     {
-	     if (cq->err != NULL)
-	       {
-	       cq->perc.Hide();
-	       fprintf(cq->err, _("\nWarning: Double MarkToC %d inside %d, second one will be ignored!"),
-                       (int)b, (int)(cq->attr.stack[i]-First_com_section));
-	       }
-	     return;
-	     }
-	}
-
+  for(unsigned i=0; i<cq->attr.Closed_Depth; i++)
+  {
+    if(cq->attr.stack[i] >= First_com_section &&
+    cq->attr.stack[i] <= Last_com_section)
+    {
+      if (cq->err != NULL)
+      {
+         cq->perc.Hide();
+	 fprintf(cq->err, _("\nWarning: Double MarkToC %d inside %d, second one will be ignored!"),
+                 (int)b, (int)(cq->attr.stack[i]-First_com_section));
+      }
+      return;
+    }
+  }
 
   if (cq->FirstSection > 100)
-	{			   /*setup for 1'st section in the document*/
-	cq->FirstSection = 0;
-	if (b == 1) cq->FirstSection = 1;
-	}
-  if (b > 0) b -= cq->FirstSection;
+  {			   /*setup for 1'st section in the document*/
+    cq->FirstSection = 0;
+    if(b == 1) cq->FirstSection = 1;
+  }
+  if(b > 0) b -= cq->FirstSection;
 
   b += OutputStyle;
   if (b > Last_com_section) return;
@@ -2187,7 +2191,7 @@ void Suppress(TconvertedPass1 *cq, char WP)
     suppress="";
     }
 
-  sprintf(cq->ObjType,"%sSuppress:%s%s%s%s",suppress,HA?" HA":"",HB?" HB":"",FA?" FA":"",FB?" FB":"");
+  snprintf(cq->ObjType, sizeof(cq->ObjType),"%sSuppress:%s%s%s%s",suppress,HA?" HA":"",HB?" HB":"",FA?" FA":"",FB?" FB":"");
 }
 
 
@@ -2199,7 +2203,7 @@ void Tab(TconvertedPass1 *cq, char WP)
 #endif
 int j;
 uint16_t wpu;
-int tabnum, new_tabs, FORLIM;
+int tabnum, new_tabs;
 const char *TabType="";
 
   if (cq->envir != 'I' && cq->envir != 'i' && cq->envir != 'B' && !cq->nomore_valid_tabs
@@ -2259,15 +2263,15 @@ const char *TabType="";
      else wpu -= cq->WP_sidemargin;  /* Correctie ivm WP kantlijn */
 
     tabnum = 0;
-    FORLIM = cq->num_of_tabs;
-    for (j = 1; j <= FORLIM; j++)
-      {   /* Bepaal welke tabpos */
+    const int FORLIM = cq->num_of_tabs;
+    for(j=1; j<=FORLIM; j++)
+    {   /* Bepaal welke tabpos */
       if (wpu >= cq->tabpos[j-1]) tabnum = j;
-      }
+    }
 
     new_tabs = tabnum - cq->latex_tabpos;
 
-    for(j=0;j<cq->attr.Closed_Depth;j++)
+    for(j=0; j<cq->attr.Closed_Depth; j++)
     	{
 	if(cq->attr.stack[j]>=0x10 && cq->attr.stack[j]<=0x13)
         	{		/* \section{ attribute found */
@@ -2310,7 +2314,7 @@ NoTab:putc(' ', cq->strip);
       return;
       }
 
-  sprintf(cq->ObjType,"Tab%s",TabType);
+  snprintf(cq->ObjType, sizeof(cq->ObjType),"Tab%s",TabType);
 }
 
 
@@ -2342,7 +2346,7 @@ void TableOfContents(TconvertedPass1 *cq, char WP)
 	case  2:if(WP>4) fread(&ListSubType, 1, 1, cq->wpd);
 		else ListSubType=0;
 		ListType = (ListType & 0xF) + 1;
-		sprintf(cq->ObjType, "%d",ListType);
+		snprintf(cq->ObjType, sizeof(cq->ObjType), "%d",ListType);
 		ListName=_("List ");
 		ListName+=cq->ObjType;
 		b=ListName() IN UserLists;
@@ -2353,9 +2357,9 @@ void TableOfContents(TconvertedPass1 *cq, char WP)
 		fprintf(cq->strip, "\\ShowUserList{l%c}{%s}",b+'a',ListName());
 		cq->line_term = 's';   /* Soft return */
 		NewLine(cq);
-		sprintf(cq->ObjType, "Def Mark:List,%d:%d",(int)ListType,(int)ListSubType+1);
+		snprintf(cq->ObjType, sizeof(cq->ObjType), "Def Mark:List,%d:%d",(int)ListType,(int)ListSubType+1);
 		break;
-	case  3:sprintf(cq->ObjType, "!Def Mark:ToA,%d",(int)(ListType & 0xF +1));
+	case  3:snprintf(cq->ObjType, sizeof(cq->ObjType), "!Def Mark:ToA,%d",(int)(ListType & 0xF +1));
 // !!!!!!!!! The tables of autorities are not converted yet
 		break;
 
@@ -2383,7 +2387,7 @@ void Terminate_Line(TconvertedPass1 *cq, char line_term)
 	}
   
   if(line_term=='h' || line_term=='P')
-    for(int j=0; j<cq->attr.Opened_Depth; j++)		// Look for subscript and superscript.
+    for(unsigned j=0; j<cq->attr.Opened_Depth; j++)		// Look for subscript and superscript.
       {
       if(cq->attr.stack[j]==5 || cq->attr.stack[j]==6)	// subscript or superscript
         {
@@ -2458,11 +2462,11 @@ if(type==6)
      fprintf(cq->strip, "\\widowpenalty %d ", (type&1)?150:0 );
      fprintf(cq->strip, "\\clubpenalty %d ", (type&2)?150:0 );
 
-     sprintf(cq->ObjType, "Wid%s/Orph:%s",
+     snprintf(cq->ObjType, sizeof(cq->ObjType), "Wid%s/Orph:%s",
          (type==2||type==1)?((type&1)?":On":":Off"):"",
 	 (type&2)?"On":"Off");
      }
-  else sprintf(cq->ObjType, "!Wid/Orph:%d",type);
+  else snprintf(cq->ObjType, sizeof(cq->ObjType), "!Wid/Orph:%d",type);
 
 }
 
