@@ -430,7 +430,7 @@ string StrEnd;
       fread(&by, 1, 1, wpd);
       if(by <= '\005' || by == 0xEA) break;
 
-      if(by == 169) by = '-';
+      if(by == 0xA9) by = '-';
       if(by == '\n' || by == '\015' || by == '&' || by == '~' ||
 	  by == '(' || by == ')' || by == '}' || by == '{' ||
 	  by == '|' ||
@@ -463,7 +463,7 @@ string StrEnd;
 	    StrBeg += FixFormulaStrFromTeX(StrEnd, wchr_code>>8);
 	    StrEnd.erase();
 
-	    sprintf(ObjType, "%d,%d",wchr_code & 0xFF,wchr_code>>8);
+	    snprintf(ObjType, sizeof(ObjType), "%d,%d",wchr_code & 0xFF,wchr_code>>8);
 	    ActualPos+=4;	//And sized only 2 (4) BYTES??
 
 	    fread(&by, 1, 1, wpd);
@@ -524,7 +524,7 @@ uint16_t count_xx;
   initBox(Box);
   BoxType=subby;
   if(BoxType>=6) {		/* Unknown Box */
-		 sprintf(ObjType, "!Box %d", BoxType);
+		 snprintf(ObjType, sizeof(ObjType), "!Box %d", BoxType);
 		 return;
 		 }
   if(BoxType==4) FormulaNo++;
@@ -547,7 +547,7 @@ uint16_t count_xx;
   if(ActualPos+1+count_xx*8>end_of_code)
     {
     Box.CaptionSize = 0;
-    sprintf(ObjType,"!%s",BoxNames[BoxType]);
+    snprintf(ObjType, sizeof(ObjType),"!%s",BoxNames[BoxType]);
     return;
     }
   else
@@ -629,7 +629,7 @@ uint16_t count_xx;
 		end;*/
 	    break;
 
-    default:sprintf(ObjType,"!%s",BoxNames[BoxType]);
+    default:snprintf(ObjType, sizeof(ObjType),"!%s",BoxNames[BoxType]);
 	    goto UnknownEquType;
     }
 
@@ -657,7 +657,7 @@ NoColumns = getc(wpd);
 
 Column(this,NoColumns);
 
-sprintf(ObjType, "Col Def:%d",(int)NoColumns);
+snprintf(ObjType, sizeof(ObjType), "Col Def:%d",(int)NoColumns);
 }
 
 
@@ -675,7 +675,7 @@ const char *RetCharStr=NULL;
   WpCharSet = fgetc(wpd);
   Char = fgetc(wpd);
 
-  sprintf(ObjType, "%d %d,%d",MacChar,WpCharSet,Char);
+  snprintf(ObjType, sizeof(ObjType), "%d %d,%d",MacChar,WpCharSet,Char);
   if(WpCharSet<12)
     {
     RetCharStr = Ext_chr_str((uint16_t)WpCharSet*256 + Char, this, ConvertCpg);
@@ -936,7 +936,7 @@ char b;
   fwrite(&b, 1, 1, table);
   Wr_word(table,CurrentSpacing);
 
-  sprintf(ObjType, "Line Spacing %2.2f",float(CurrentSpacing)/128);
+  snprintf(ObjType, sizeof(ObjType), "Line Spacing %2.2f",float(CurrentSpacing)/128);
 }
 
 
@@ -1209,11 +1209,11 @@ SkipUndoStuff:
 		perc.Hide();
 		fprintf(err, _("\nWarning: Strange Undo type:%d!"),(int)subby);
 		}
-	   sprintf(ObjType, "!Undo (?%d:%d)"+(::UndoRedo?1:0),subby,(int)Level);
+	   snprintf(ObjType, sizeof(ObjType), "!Undo (?%d:%d)"+(::UndoRedo?1:0),subby,(int)Level);
 	   return;
    }
 
-  sprintf(ObjType, "!Undo (%s:%d)"+(::UndoRedo?1:0), UndoType,(int)Level);
+  snprintf(ObjType, sizeof(ObjType), "!Undo (%s:%d)"+(::UndoRedo?1:0), UndoType,(int)Level);
 }
 
 
@@ -1428,16 +1428,16 @@ void TconvertedPass1_WP3::ProcessKeyWP3(void)
 
 	case 0xC8: strcpy(ObjType,"!Dbl Byte Script Char"); break; //Double Byte Script Character
 
-        case 0xCC: sprintf(ObjType,"!Tmp Marker %d",subby); break;
+        case 0xCC: snprintf(ObjType, sizeof(ObjType),"!Tmp Marker %d",subby); break;
 	case 0xCD: Undo3(NewPos);  break;
-	case 0xCE: if(subby==0) sprintf(ObjType,"!Tmp Ch Spc");    // Temp Character Space Function
-		   if(subby==1) sprintf(ObjType,"!Tmp Ch SpcExt"); // Temp Space-Extra Function
-		   if(subby==0xFF) sprintf(ObjType,"!Tmp Ch Ext"); //Temp Char-Extra Function
+	case 0xCE: if(subby==0) snprintf(ObjType, sizeof(ObjType),"!Tmp Ch Spc");    // Temp Character Space Function
+		   if(subby==1) snprintf(ObjType, sizeof(ObjType),"!Tmp Ch SpcExt"); // Temp Space-Extra Function
+		   if(subby==0xFF) snprintf(ObjType, sizeof(ObjType),"!Tmp Ch Ext"); //Temp Char-Extra Function
 		   break;
 
 	case 0xD0:switch(subby)
                     {
-                    case 0x01: sprintf(ObjType,"!Set Hor Margin"); break;
+                    case 0x01: snprintf(ObjType, sizeof(ObjType),"!Set Hor Margin"); break;
                     case 0x02: LineSpacing3(); break;
 	            case 0x06: Justification(this,3); break;
                     case 0x07: Suppress(this,3); break;
