@@ -53,9 +53,9 @@ const char *InputPasswordAgain="\nWarning! Password checksum does not match file
 
 
 /** This function computes checksum for the given password. */
-static WORD CheckSum(char *PassWord)
+static uint16_t CheckSum(char *PassWord)
 {
-WORD csum;
+uint16_t csum;
 
 csum=0;
 if(PassWord==NULL) return(0);
@@ -65,7 +65,7 @@ while(*PassWord!=0)
 	if( *PassWord>='a' && *PassWord<='z')    /* convert to upper case */
 			*PassWord -= 'a'-'A';
 
-	csum = ( (csum >> 1) | ( csum << 15) ) ^ ( ((WORD)*PassWord)<<8 );
+	csum = ( (csum >> 1) | ( csum << 15) ) ^ ( ((uint16_t)*PassWord)<<8 );
 	PassWord++;
 	}
 return(csum);
@@ -76,12 +76,12 @@ return(csum);
 static void DecryptWP345(FILE *Encrypted, FILE *Decrypted, const string & PassWord, FILE *ErrorFile)
 {
 char *buf;
-WORD idx;                     /* index into buffer */
-WORD pidx;                    /* index down password */
-BYTE xmask;                   /* XOR mask */
-DWORD len;
-DWORD pos = ftell(Encrypted);
-DWORD fsize = FileSize(Encrypted);
+uint16_t idx;                     /* index into buffer */
+uint16_t pidx;                    /* index down password */
+uint8_t xmask;                   /* XOR mask */
+uint32_t len;
+uint32_t pos = ftell(Encrypted);
+uint32_t fsize = FileSize(Encrypted);
 
  if(ErrorFile==NULL) ErrorFile=stderr;
 
@@ -143,11 +143,11 @@ int TconvertedPass1_xWP5::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_WP5_encrypted() ");fflush(log);
 #endif
-WORD encryption;
+uint16_t encryption;
 string temp_filename;
-DWORD DocumentStart;	/* position in file */
+uint32_t DocumentStart;	/* position in file */
 FILE *DecryptedFile = NULL;
-BYTE SmallBuf[16];
+uint8_t SmallBuf[16];
 TconvertedPass1 *cqPass1;
 int RetVal=0;
 
@@ -187,19 +187,22 @@ Ignore:
 		GetExtension(wpd_filename())- wpd_filename()) + ".$$$";
 
 	if((DecryptedFile=OpenWrChk(temp_filename,"wb",err))==NULL)
-			RunError(6,temp_filename);
+	{
+	  RunError(6,temp_filename);
+	  return -1;
+	}
 
 	fseek(wpd,0l,SEEK_SET);
 	fread( SmallBuf, 1, 16, wpd);
-	SmallBuf[12] = SmallBuf[13] = 0;          /* reset encryption=0 */
-	fwrite( SmallBuf, 1, 16, DecryptedFile ); /* write out first part of WP5.1 file */
+	SmallBuf[12] = SmallBuf[13] = 0;		/* reset encryption=0 */
+	fwrite( SmallBuf, 1, 16, DecryptedFile );	/* write out first part of WP5.1 file */
 
 	DecryptWP345(wpd,DecryptedFile,wpd_password,err);
 	} /* ver5 */
 
 
   if(DecryptedFile!=NULL) /* Now perform normal conversion */
-    {
+  {
     fclose(DecryptedFile);
     if((DecryptedFile=fopen(temp_filename,"rb"))==NULL) return(0);
 
@@ -211,7 +214,7 @@ Ignore:
 #ifndef DEBUG
     if(EraseStrip) unlink(temp_filename);
 #endif		// DEBUG
-    }
+  }
   delete cqPass1;
 
 return(RetVal);
@@ -224,11 +227,11 @@ int TconvertedPass1_xWP3::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_WP3_encrypted() ");fflush(log);
 #endif
-WORD encryption;
+uint16_t encryption;
 string temp_filename;
-DWORD DocumentStart;	/* position in file */
+uint32_t DocumentStart;	/* position in file */
 FILE *DecryptedFile=NULL;
-BYTE SmallBuf[16];
+uint8_t SmallBuf[16];
 TconvertedPass1 *cqPass1;
 int RetVal=0;
 
@@ -267,7 +270,10 @@ Ignore:
 		GetExtension(wpd_filename())- wpd_filename()) + ".$$$";
 
 	if((DecryptedFile=OpenWrChk(temp_filename,"wb",err))==NULL)
-			RunError(6,temp_filename);
+	{
+	  RunError(6,temp_filename);
+	  return -1;
+	}
 
 	fseek(wpd,0l,SEEK_SET);
 	for(unsigned i=0; i<(DocumentStart/16); i++) /* copy everythink till to DocumentStart */
@@ -306,7 +312,7 @@ return(RetVal);
 /** WP1.x and WP4.x decryptor. */
 int TconvertedPass1_xWP4::Convert_first_pass(void)
 {
-WORD encryption, checksum;
+uint16_t encryption, checksum;
 string temp_filename;
 FILE *DecryptedFile=NULL;
 TconvertedPass1 *cqPass1;
@@ -316,74 +322,74 @@ const char *Module;
   fseek(wpd,4,SEEK_CUR);	// FF FE 61 61
   RdWORD_HiEnd(&encryption, wpd);
   if(encryption!=0)
-	{
-	checksum = CheckSum(wpd_password());
-	if(checksum!=encryption && ((checksum>>8)|((checksum<<8)&0xFF00))!=encryption)
-	   {
-           if(length(wpd_password)<=0) 
-	       ObtainPassword(wpd_password);
+  {
+    checksum = CheckSum(wpd_password());
+    if(checksum!=encryption && ((checksum>>8)|((checksum<<8)&0xFF00))!=encryption)
+    {
+      if(length(wpd_password)<=0) 
+          ObtainPassword(wpd_password);
 
-	   checksum = CheckSum(wpd_password());
-	   while(checksum!=encryption && ((checksum>>8)|((checksum<<8)&0xFF00))!=encryption)
-	      {
-              if(Verbosing<=-1) return -1;	// Silence mode selected, return immediatelly.
+      checksum = CheckSum(wpd_password());
+      while(checksum!=encryption && ((checksum>>8)|((checksum<<8)&0xFF00))!=encryption)
+      {
+        if(Verbosing<=-1) return -1;	// Silence mode selected, return immediatelly.
 
-	      switch(YesNoIgnore(_(InputPasswordAgain)))
-		 {
-		 case 'Y':ObtainPassword(wpd_password);
+        switch(YesNoIgnore(_(InputPasswordAgain)))
+        {
+           case 'Y':ObtainPassword(wpd_password);
 			  checksum = CheckSum(wpd_password());
 			  break;
-		 case 'N':return -1;
-		 case 'I':goto Ignore;
-		 }
-	      }
-	   }
+          case 'N':return -1;
+          case 'I':goto Ignore;
+        }
+      }
+    }
 Ignore:
-	temp_filename = copy(wpd_filename,0,
-			     GetExtension(wpd_filename)- wpd_filename()) + ".$$$";
-	if((DecryptedFile=OpenWrChk(temp_filename,"wb",err))!=NULL)
-	   DecryptWP345(wpd,DecryptedFile,wpd_password,err);
-	} /* ver4 */
+    temp_filename = copy(wpd_filename,0,
+		     GetExtension(wpd_filename)- wpd_filename()) + ".$$$";
+    if((DecryptedFile=OpenWrChk(temp_filename,"wb",err))!=NULL)
+    DecryptWP345(wpd,DecryptedFile,wpd_password,err);
+  } /* ver4 */
   else
-    {      
+  {
     RunError(0x203);  /* something gets wrong - no idea */
     return -1;
-    }
+  }
 
   if(DecryptedFile!=NULL)
-    {
+  {
     fclose(DecryptedFile);
     if((DecryptedFile=fopen(temp_filename,"rb"))==NULL)   //reopen file for reading
 	return(-1);
-    }
+  }
   else
-    {
+  {
     RunError(6,temp_filename());
     return -1;
-    }
+  }
 
   if((checksum>>8) == (checksum&0xFF))
-    {
+  {
     CheckFileFormat(DecryptedFile,FilForD);
     fseek(DecryptedFile,0,SEEK_SET);	    //rewind document
     //printf("\nDocumentType: %s, Converter %s, Probability %g",chk(FilForD.DocumentType),chk(FilForD.Converter),FilForD.Probability);
     Module = FilForD.Converter;
     if(Module==NULL || *Module==0)
-      {
+    {
       Module="WP4.x";	// WP4 has lo endian
       if(err!=NULL)
-	{   /**/
-	fprintf(err,_("\nAutodetection is unsure, default: %s."), chk(Module));
-	}
+      {   /**/
+        fprintf(err,_("\nAutodetection is unsure, default: %s."), chk(Module));
       }
     }
+  }
   else
-    {
+  {
     if(checksum==encryption)
       Module="WP4.x";	// WP4 has lo endian
     else
       Module="WP1.x";	// WP1 has swapped bytes - high endian
-    }
+  }
 
   cqPass1=GetConverter(Module);
   if(cqPass1==NULL)		// module is not present
