@@ -26,7 +26,7 @@
 
 list HTMLChars(Table_html,sizeof(Table_html)/sizeof(char *));
 
-#define HTMLVersion "0.31"
+#define HTMLVersion "0.32"
 
 
 /** Base class for HTML document conversion. */
@@ -744,6 +744,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
 	     break;
 
 	case XML_tag:
+        case XML_closedtag:
                TAG = copy(this->TAG,1,length(this->TAG)-2);	//Normal tag <xxx>
 	       if(TAG.length() <= 0) break;
                for(i=0; i<sizeof(OpenTags)/sizeof(TagStruct); i++)
@@ -758,6 +759,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
 	       break;
 
 	case XML_closetag:
+	case XML_closedclosetag:
                TAG = copy(this->TAG,2,length(this->TAG)-3);	//Closing tag </xxx>
 	       if(TAG.length() <= 0) break;
                for(i=0; i<sizeof(CloseTags)/sizeof(TagStruct); i++)
