@@ -634,13 +634,13 @@ int16_t LineSpacing;
       cq->subby = cq->by>>4;
       if(cq->subby & 8) Rd_nudge(cq->wpd, cq->nudge);
       if(cq->subby & 4) Ruller=fgetc(cq->wpd);
-      if(cq->subby & 1)	{sprintf(cq->ObjType, "LINE{}");return;}
+      if(cq->subby & 1)	{snprintf(cq->ObjType, sizeof(cq->ObjType), "LINE{}");return;}
       }
  else {
       cq->subby=fgetc(cq->wpd);	//[options]
       if(cq->subby & MtefO_NUDGE) Rd_nudge(cq->wpd, cq->nudge);
       if(cq->subby & MtefO_LINE_LSPACE) Rd_word(cq->wpd, (uint16_t *)&LineSpacing);
-      if(cq->subby & MtefO_LINE_NULL) {sprintf(cq->ObjType, "LINE{}");return;}
+      if(cq->subby & MtefO_LINE_NULL) {snprintf(cq->ObjType, sizeof(cq->ObjType), "LINE{}");return;}
       }
 
  OldBy = cq->by;
@@ -657,7 +657,7 @@ int16_t LineSpacing;
 	}
  cq->recursion--;
  cq->by=OldBy;
- sprintf(cq->ObjType, "~LINE #%d", iLineNo);
+ snprintf(cq->ObjType, sizeof(cq->ObjType), "~LINE #%d", iLineNo);
 }
 
 
@@ -679,8 +679,8 @@ string arg[4];
       }
   else
       {
-      cq->subby=fgetc(cq->wpd);	//[options]
-      if(cq->subby && MtefO_NUDGE) Rd_nudge(cq->wpd, cq->nudge);
+      cq->subby = fgetc(cq->wpd);	//[options]
+      if(cq->subby & MtefO_NUDGE) Rd_nudge(cq->wpd, cq->nudge);
       }
   Embell=fgetc(cq->wpd);
 
@@ -719,7 +719,7 @@ string arg[4];
 	 }
        }
 
-sprintf(cq->ObjType, "EMBELL %u",(unsigned)Embell);
+snprintf(cq->ObjType, sizeof(cq->ObjType), "EMBELL %u",(unsigned)Embell);
 }
 
 
@@ -813,7 +813,7 @@ char Num[2]="0";
   cq->recursion--;
   cq->by=OldBy;
 Finish:
-  sprintf(cq->ObjType, "~TMPL %d,%d",(int)Selector,(int)Variation);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "~TMPL %d,%d",(int)Selector,(int)Variation);
 }
 
 
@@ -842,7 +842,7 @@ uint8_t Ruler;
 	Ruler=fgetc(cq->wpd);
 	}
 
-  sprintf(cq->ObjType, "!PILE");
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "!PILE");
 }
 
 
@@ -888,7 +888,7 @@ Raster1DAbstract *row_parts=NULL,*col_parts=NULL;
 ExitMatrix:
     if(row_parts) {delete row_parts; row_parts=NULL;}
     if(col_parts) {delete col_parts; col_parts=NULL;}
-    sprintf(cq->ObjType, "!MATRIX");
+    snprintf(cq->ObjType, sizeof(cq->ObjType), "!MATRIX");
     return;
     }
 
@@ -970,7 +970,7 @@ ExitMatrix:
   ProcessKeyMTEFSymbol(cq);	//and process it
 
   cq->by=OldBy;
-  sprintf(cq->ObjType, "~MATRIX");
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "~MATRIX");
 }
 
 
@@ -987,7 +987,7 @@ uint8_t Tabs;
   Tabs=fgetc(cq->wpd);		//[n_stops]
   fseek(cq->wpd,3*Tabs,SEEK_CUR);
 
-  sprintf(cq->ObjType, "!RULER");
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "!RULER");
 }
 
 
@@ -1017,7 +1017,7 @@ char c;
 	CharStyle = fgetc(cq->wpd);		//[character style]
 	}
 
-  sprintf(cq->ObjType, "!FONT_STYLE");
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "!FONT_STYLE");
 }
 
 
@@ -1054,7 +1054,7 @@ const char *ChrStr;
 	  }
      }
 
-  sprintf(cq->ObjType, "CHAR %d:0x%X %c",(int)Typeface,CHAR,(char)CHAR);
+  snprintf(cq->ObjType, sizeof(cq->ObjType), "CHAR %d:0x%X %c",(int)Typeface,CHAR,(char)CHAR);
 
   if(CHAR>=0xEB00 && CHAR<=0xEB08) //mapped spaces into UNICODE glyphspace
     {
@@ -1076,7 +1076,7 @@ const char *ChrStr;
     if(strchr(ChrStr,'\\')!=NULL || strchr(ChrStr,'$')!=NULL)
 	{
 	string s(ChrStr);
-	cq->Formula+=FixFormulaStrFromTeX(s,CHAR/256);
+	cq->Formula += FixFormulaStrFromTeX(s,CHAR/256);
 	}
     else
 	cq->Formula+=ChrStr;
@@ -1103,7 +1103,7 @@ uint8_t Nibble;
 
  switch(by)
 	{
-	case 0: sprintf(cq->ObjType, "END");	break;	//EndRecord;
+	case 0: snprintf(cq->ObjType, sizeof(cq->ObjType), "END");	break;	//EndRecord;
 	case 1: MTEF_LINE(cq);			break;
 	case 2: MTEF_CHAR(cq);			break;
 	case 3: MTEF_TMPL(cq);			break;
@@ -1112,20 +1112,20 @@ uint8_t Nibble;
 	case 6: MTEF_EMBELL(cq);		break;
 	case 7: MTEF_RULER(cq);			break;
 	case 8: MTEF_FONTSTYLE(cq);		break;
-	case 9: sprintf(cq->ObjType,"SIZE"); GetSize(cq);	break;
-	case 10:sprintf(cq->ObjType,"FULL"); GetSize(cq);	break;
-	case 11:sprintf(cq->ObjType,"SUB");  GetSize(cq);	break;
-	case 12:sprintf(cq->ObjType,"SUB2"); GetSize(cq);	break;
-	case 13:sprintf(cq->ObjType,"SYM");  GetSize(cq);	break;
-	case 14:sprintf(cq->ObjType,"SUBSYM");GetSize(cq);	break;
+	case 9: snprintf(cq->ObjType, sizeof(cq->ObjType),"SIZE"); GetSize(cq);	break;
+	case 10:snprintf(cq->ObjType, sizeof(cq->ObjType),"FULL"); GetSize(cq);	break;
+	case 11:snprintf(cq->ObjType, sizeof(cq->ObjType),"SUB");  GetSize(cq);	break;
+	case 12:snprintf(cq->ObjType, sizeof(cq->ObjType),"SUB2"); GetSize(cq);	break;
+	case 13:snprintf(cq->ObjType, sizeof(cq->ObjType),"SYM");  GetSize(cq);	break;
+	case 14:snprintf(cq->ObjType, sizeof(cq->ObjType),"SUBSYM");GetSize(cq);	break;
 
-	case 17:sprintf(cq->ObjType, "FONT_DEF");
+	case 17:snprintf(cq->ObjType, sizeof(cq->ObjType), "FONT_DEF");
 		cq->subby=fgetc(cq->wpd);	//[enc_def_index]
 		cq->subby=1;
 		while(cq->subby!=0 && !feof(cq->wpd)) cq->subby=fgetc(cq->wpd);
 		break;
 
-	case 18:sprintf(cq->ObjType, "EQN_PREFS");
+	case 18:snprintf(cq->ObjType, sizeof(cq->ObjType), "EQN_PREFS");
 		cq->subby=fgetc(cq->wpd);	//[options]
 		size=fgetc(cq->wpd);
 		Nibble=0;
@@ -1146,7 +1146,7 @@ uint8_t Nibble;
 		fseek(cq->wpd,size*2,SEEK_CUR);
 		break;
 
-	case 19:sprintf(cq->ObjType, "ENCODING_DEF");
+	case 19:snprintf(cq->ObjType, sizeof(cq->ObjType), "ENCODING_DEF");
 		cq->subby=1;
 		while(cq->subby!=0 && !feof(cq->wpd)) cq->subby=fgetc(cq->wpd);
 		break;
