@@ -24,7 +24,7 @@
 
 #include "raster.h"
 
-#include "wp2latex.h"
+#include"wp2latex.h"
 
 #include "cp_lib/cptran.h"
 
@@ -1656,7 +1656,7 @@ int ch;
 
  if(cq->Unicode==NULL)
 	{
-	sprintf(dummy,"U%ld ",cq->lParam);
+	snprintf(dummy,sizeof(dummy),"U%ld ",cq->lParam);
 	CharacterStr(cq,dummy);
 	}
  else {
@@ -1907,7 +1907,7 @@ int KeywordType;
 		      ChangeCpTranslator(this);
 		      }
 		    }
-		  sprintf(ObjType,"Font:%ld",lParam);
+		  snprintf(ObjType, sizeof(ObjType),"Font:%ld",lParam);
 		  break;
 		  }
 	      if(Keyword=="fonttbl")
