@@ -64,7 +64,7 @@ public:
      DeviceContext_xMF &operator=(const DeviceContext_xMF & BaseDC);
 
      PS_State PSS;
-     WORD MapMode;
+     uint16_t MapMode;
      char MixMode;
 };
 
@@ -104,8 +104,8 @@ public:
      void PushDC(void);
      void PopDC(void);
 
-     SWORD YOffset, XOffset;
-     SWORD YExtent, XExtent;
+     int16_t YOffset, XOffset;
+     int16_t YExtent, XExtent;
      
      const CpTranslator *PsNativeCP;
      const CpTranslator *PsNativeSym;
