@@ -78,36 +78,37 @@ Flags:'h';       Hard return
 		  1 Valid character placed on the line */
 
 /*WP2LaTex switches: -1:disabled; 0:automatically enabled; 1: forced to enable*/
-int8_t   Accents = STYLE_NOTUSED,
-	AmsMath = -1,
-        Amssymb = -1,		// Totaly Disabled
+int8_t  Accents = STYLE_NOTUSED,
+	AmsMath = STYLE_DISABLED,
+        Amssymb = STYLE_DISABLED,
         arabtex = STYLE_NOTUSED,
-	Arevmath = -1,		// Totaly Disabled
+	Arevmath = STYLE_DISABLED,
         Cyrillic = STYLE_NOTUSED,
 	cjHebrew = STYLE_NOTUSED,
-	colors = STYLE_NOTUSED,	// Only for LaTex 2.0e
-	textcomp = -1,
+	colors = STYLE_NOTUSED,			// Only for LaTex 2.0e
+	textcomp = STYLE_NOTUSED,
 	EndNotes = STYLE_NOTUSED,
-	FancyHdr = -1,
-	Columns = 1,		// -1 disabled; 0 auto two; 1 auto multi; 2 forced two; >2 forced multi*/
-	InputPS = IMG_graphicx,	// -1 disabled; 0 auto InputPS.sty; 1 InputPS.sty; 2 auto graphicx.sty; 3 graphicx.sty; 4 auto epsfig.sty; 5 epsfig.sty; 8 auto graphics.sty; 9 graphics.sty;
+	FancyHdr = STYLE_DISABLED,
 	pifont = STYLE_NOTUSED,
 	PostScript = STYLE_NOTUSED,
-	MakeIdx = -1,
-	Wasy = -1,		// Totaly Disabled	
+	MakeIdx = STYLE_DISABLED,
+	Wasy = STYLE_DISABLED,
 	LaTeXsym = 0,
-	Bbm = -1,
-	TIPA = -1,
-	fontenc = -1,
-	Rsfs = -1,
+	Bbm = STYLE_DISABLED,
+	TIPA = STYLE_DISABLED,
+	fontenc = STYLE_DISABLED,
+	Rsfs = STYLE_DISABLED,
 	Ulem = 0,		// Enabled on demand
 	rus_yo = 0,
-	LongTable = -1,
-	SaveWPG = -1,
+	LongTable = STYLE_DISABLED,
         Rotate = STYLE_NOTUSED,
         Scalerel = STYLE_NOTUSED,
         mxedruli = STYLE_NOTUSED,
 	LineNo = STYLE_NOTUSED;
+		// special handling
+int8_t	Columns = 1,		// -1 disabled; 0 auto two; 1 auto multi; 2 forced two; >2 forced multi
+	InputPS = IMG_graphicx;	// -1 disabled; 0 auto InputPS.sty; 1 InputPS.sty; 2 auto graphicx.sty; 3 graphicx.sty; 4 auto epsfig.sty; 5 epsfig.sty; 8 auto graphics.sty; 9 graphics.sty;
+int8_t	SaveWPG = -1;
 bool Index = false,
         Interactive = true,
 	NFSS = false,
@@ -118,7 +119,7 @@ bool Index = false,
 
 string force, FORCE;
 int LaTeX_Version=0x300; /* 0x209=LaTeX 2.09; 0x300=LaTex 3.0 (or 2e) */
-unsigned short OutCodePage, WPcharset;
+uint16_t OutCodePage, WPcharset;
 FFormatDetect FilForD;
 #ifdef _has_MemStreams
 int UseMemStream=0;
@@ -1605,7 +1606,7 @@ void PrintPackageList(void)
 
 
 /// See which CPs are supported by inputenc: https://ctan.math.illinois.edu/macros/latex/base/inputenc.pdf
-const TOutCodePage OutCodepages[12] =
+const TOutCodePage OutCodepages[14] =
 {
   {"852", "internalTOcp852", 852, true},
   {"866", NULL, 866, false},
@@ -1618,7 +1619,9 @@ const TOutCodePage OutCodepages[12] =
   {"ISO-8859-2", "internalTOiso_8859_2", ISO8859_2, true},
   {"KOI8R", NULL, KOI8R, false},
   {"UTF8", "internalTOunicode", UTF8, true},
-  {"UTF-8", "internalTOunicode", UTF8, true}
+  {"UTF-8", "internalTOunicode", UTF8, true},
+  {"none",NULL,0,false},
+  {"plaintext",NULL,0,false}
 };
 
 
@@ -1717,6 +1720,8 @@ int p;
 	     continue;
 	     }
 	  OutCodePage = 0;
+          CPStyles = false;
+          Convert2Target = NULL;
 	  Heading();
 	  printf(_("Warning: Unknown output codepage \"%s\"!"),name);
 	  continue;
