@@ -35,7 +35,7 @@
 
 //Non standard include files
 #include "stringa.h"
-#include <lists.h>
+#include "lists.h"
 #include "wp2latex.h"
 
 #ifdef _MSC_VER
@@ -49,6 +49,13 @@
  #endif
 #endif
 
+#ifdef __BORLANDC__
+ #include "cp_lib/cptran.h"
+#else
+ #include "cptran.h"
+#endif
+
+
 //#include <alloc.h>
 
 
@@ -662,7 +669,20 @@ TconvertedPass1 *cqPass1;
 	/* Default initialization */
   Verbosing = 1;
   TexChars = false;
-  OutCodePage = 0;	/*unknown - no 8 bit code generated*/
+
+/*	// It is not wise to make default UTF8, there are lot of unsolved problems yet.
+  Convert2Target = GetTranslator("internalTOunicode");
+  CPStyles = Convert2Target!=NULL;
+  if(CPStyles)
+  {
+    OutCodePage = UTF8;		// unknown - no 8 bit code generated.
+  }
+  else
+*/
+  {
+    OutCodePage = 0;
+  }
+
   WPcharset = 1;	/*common charset 1*/
   ExtendedCheck = true;	/*true*/
   FixSpaces = false;
