@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"4.17"
-#define VersionDate	"14 Aug 2025"  /* day (space) month (space) full year */
+#define VersionWP2L	"4 pre 19"
+#define VersionDate	"29 Dec 2025"  /* day (space) month (space) full year */
 
 
 /** Constants for a flag InputPS */
@@ -30,7 +30,7 @@ typedef enum
     IMG_graphics =	8
 } EflagsInputPS;
 
-extern unsigned short OutCodePage, WPcharset;
+extern uint16_t OutCodePage, WPcharset;
 extern bool Index, Interactive, NFSS, TABs, twoside, ExactFnNumbers, CPStyles,
 	 EraseStrip, UndoRedo, Noclobber;
 extern int8_t arabtex, Cyrillic, colors, EndNotes, FancyHdr, Columns, cjHebrew, InputPS, MakeIdx,
@@ -373,7 +373,7 @@ void BoxTexFoot(TconvertedPass1 *cq, const TBox & Box);
  char Remove1stArg(string & str,string & arg);
  bool RemoveLastArg(string & str,string & arg);
  bool RemoveSymbol(string & str1,string & str2,const char * symbol);
- string & FixFormulaStrFromTeX(string & StrEnd,const char chr_set=0);
+ string & FixFormulaStrFromTeX(string & StrEnd, const char chr_set=0);
  bool OptimizeFormulaStr(TconvertedPass1 *cq, string & StrBeg);
  bool FixFormula(TconvertedPass1 *cq, string & EquStr, int & Braces, int & BegBrace);
 #endif
@@ -544,12 +544,12 @@ void PrintPackageList(void);
 typedef struct
 {
   const char	*Name;
-  const char    *Translator;
-  uint16_t		Id;
+  const char	*Translator;
+  uint16_t	Id;
   bool		UseCpStyles;
 } TOutCodePage;
 
-extern const TOutCodePage OutCodepages[12];
+extern const TOutCodePage OutCodepages[14];
 
 
 #ifndef FINAL
